==> haskell-wai-handler-launch-3.0.2.4-199-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-1Dc8FUvT7x6Jvgb7GKocAL
key: wai-handler-launch-3.0.2.4-1Dc8FUvT7x6Jvgb7GKocAL
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: f9cac6881112215a286255fce2665fc0
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-1Dc8FUvT7x6Jvgb7GKocAL
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    process-1.6.5.0 streaming-commons-0.2.1.1-FltEP5lCx0137LYmTxSGHQ
    transformers-0.5.6.2 wai-3.2.2.1-CQ54CFlyR3DJGjuiF7FXOI
    warp-3.3.0-HNNNtujfbUEBHVvZf0zqu0
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-handler-launch-3.0.2.4-206-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-handler-launch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-handler-launch
version: 3.0.2.4
id: wai-handler-launch-3.0.2.4-K4vdjC9LkCBIt8xoLDp67
key: wai-handler-launch-3.0.2.4-K4vdjC9LkCBIt8xoLDp67
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
synopsis: Launch a web app in the default browser.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-handler-launch>.
category: Web
abi: afabf5fa125a903c17d53d70d52cb701
exposed: True
exposed-modules:
    Network.Wai.Handler.Launch
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-handler-launch-3.0.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-handler-launch-3.0.2.4
hs-libraries: HSwai-handler-launch-3.0.2.4-K4vdjC9LkCBIt8xoLDp67
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 http-types-0.12.3-9Oghevaq5FtBD8UlWmZNzU
    process-1.6.5.0 streaming-commons-0.2.1.1-D8HNA16k4kJDYTyULOEvOd
    transformers-0.5.6.2 wai-3.2.2.1-4WqDfhNhXZ1I8rnFCtCUIJ
    warp-3.3.0-DKvxLjnIMTz3RdDcvXOJqk
haddock-interfaces: /usr/share/doc/haskell-wai-handler-launch/html/wai-handler-launch.haddock
haddock-html: /usr/share/doc/haskell-wai-handler-launch/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
